<?php get_header();

$post_id = $post->ID;
$fields = get_fields($post_id);

// print_r($fields);

$eventbrite_event_id = $fields['eb_event_id'];
$title = $post->post_title;
$summary = isset($fields['event_summary']) ? $fields['event_summary'] : null;
$description = isset($fields['full_description']) ? $fields['full_description'] : null;
$start_date = $fields['start_datetime'] ?? null;
$end_date = $fields['end_datetime'] ?? null;
$soldout = $fields['sold_out'] ?? null;
$is_event_series = $fields['is_event_series'];
$series_dates = isset($fields['event_series_dates']) ? $fields['event_series_dates'] : null;
$venue_name = $fields['event_venue']['venue_name'];
$location = $fields['event_venue']['venue_location'];
$featured_image = isset($fields['featured_image']) ? $fields['featured_image'] : null;
$dates_array = array();
$today = strtotime(date('Y/m/d'));
$next_date = null;

if($series_dates) {

    foreach($series_dates as $date) {

        $sdate = strtotime($date['event_series_start_datetime']);
        if($sdate > $today) {
            $single_date = array(
                'start' => $date['event_series_start_datetime'],
                'end'	=> $date['event_series_end_datetime'],
            );
            array_push($dates_array, $single_date);
        }
    } 
    sort($dates_array);
    $next_date = date("D jS M", strtotime($dates_array[0]['start'])) . ' | ' . date("g:i a", strtotime($dates_array[0]['start'])) . ' - ' . date("g:i a", strtotime($dates_array[0]['end'])); ?>

<?php } else if($start_date) {
    $next_date = date("D, jS M Y, g:ia", strtotime($start_date));
} ?>


<main class="event">

	<section class="event-main container-wrap">
		<div class="container">

		    <div class="featured-image">
				<?php if($featured_image) { ?>
					<img class="featured" src="<?php echo $featured_image; ?>" alt="<?php echo $title; ?>" />
				<?php } ?>
			</div>

			<div class="overview">
                <div>
				    <h1><?php echo $title; ?></h1>
                    <p><?php echo $summary; ?></p>
                    <?php if($venue_name) { ?>
                        <p class="venue"><strong>Venue:</strong> <?php echo $venue_name; ?></p>
                    <?php } ?>
                    <?php if($next_date && count($dates_array) == 1) { ?>
                        <p><strong>Date:</strong> <?php echo $next_date; ?></p>
                    <?php }
                    if(count($dates_array) > 1) { ?>
                        <p><strong>Next Date:</strong> <?php echo $next_date; ?></p>
                        <span class="series"><span class="icon"><?php echo file_get_contents(get_template_directory() . '/assets/img/icons/icon-stack.svg'); ?></span>Multiple dates</span>
                        <button id="all-dates" class="btn" type="button">See all dates</button>
                    <?php } ?>

                </div>

                <div class="booking">
                    <?php if($soldout == true) { ?>
                        <p class="soldout-notify">This event has sold out.</p>
                    <?php } else if($fields['event_object_type'] == 'eventbrite') { ?>
                        <noscript><a href="https://www.eventbrite.co.uk/e/final-test-event-tickets-<?php echo $eventbrite_event_id; ?>" rel="noopener noreferrer" target="_blank">Buy Tickets on Eventbrite</a></noscript>
                        <button id="eventbrite-widget-modal-trigger-<?php echo $eventbrite_event_id; ?>" class="btn event-book" type="button">Book now</button>
                    <?php } else if($fields['event_object_type'] == 'custom') { 
                        if($fields['custom_booking_url']) { ?>
                            <a href="<?php echo $fields['custom_booking_url']; ?>" target="_blank" class="btn event-book" type="button">Book now</a>
                        <?php }
                    } ?>
                
                    <div class="gift-cards">
                        <h4>Gift Cards</h4>
                        <p>Gift voucher for Real Ideas ticketed events, workshops and immersive experiences.</p>
                        <div class="giftcards">
                            <button type="button" class="btn" id="load-giftup">Buy Gift Cards</button>
                        </div>
                    </div>
                </div>
            </div>            

            <?php if(count($dates_array) > 1) {
                $month = ''; ?>
                <div id="dates">
                    <div class="event-dates">
                    <?php foreach($dates_array as $d) { 
                        $m = date("F", strtotime($d['start']));
                        if($month != $m) { ?>
                            <span class="month"><?php echo $m; ?></span>
                        <?php $month = $m;
                        } ?>
                        <span class="date">
                            <span class="day"><?php echo date("D jS M", strtotime($d['start'])); ?></span>
                            <span class="time"><?php echo date("g:i a", strtotime($d['start'])); ?> - <?php echo date("g:i a", strtotime($d['end'])); ?></span>    
                        </span>
                    <?php } ?>
                    </div>
                </div>
            <?php } ?>

            <h3 class="tab_title">Description</h3>
            <?php echo $description; ?>

		</div>
	</section>

    <?php if(count($dates_array) > 1) { ?>
    <script>        
        const datesButton = document.getElementById('all-dates');
        const allDates = document.getElementById('dates');
        datesButton.addEventListener('click', function() {
            // Toggle the 'active' class on click
            allDates.classList.toggle('active');
        });
    </script>
    <?php } ?>

    <?php if($location) { ?>
	<section class="venue">
            
        <div class="map">
            <?php get_template_part('template-parts/components/google-map', '', array(
                'location'		=> $location,
                'zoom'			=> 15,
                'fullscreen'	=> true,
                'init'			=> true,
                'style'         => '[{"stylers":[{"hue":"#dd0d0d"}]},{"featureType":"road","elementType":"labels","stylers":[{"visibility":"off"}]},{"featureType":"road","elementType":"geometry","stylers":[{"lightness":100},{"visibility":"simplified"}]}]',
            )); ?>
        </div>

	</section>
    <?php } ?>

</main>

<script src="https://www.eventbrite.com/static/widgets/eb_widgets.js"></script>
<?php if($eventbrite_event_id) { ?>
<script type="text/javascript">
    var exampleCallback = function() {
        console.log('Order complete!');
    };

    window.EBWidgets.createWidget({
        widgetType: 'checkout',
        eventId: <?php echo $eventbrite_event_id; ?>,
        modal: true,
        modalTriggerElementId: 'eventbrite-widget-modal-trigger-' + '<?php echo $eventbrite_event_id; ?>',
        onOrderComplete: exampleCallback
    });
</script>
<?php } ?>

<?php get_footer();
