<?php
/**
 * Template Name: Whats On
 * 
 */

get_header();

$page_id = get_the_ID();
$organiser = get_field('page_event_organiser', $page_id);
$dates = $_GET['dates'] ?? null; ?>

<!-- <script type="text/javascript" src="https://cdn.jsdelivr.net/jquery/latest/jquery.min.js"></script> -->
<script type="text/javascript" src="https://cdn.jsdelivr.net/momentjs/latest/moment.min.js"></script>
<script type="text/javascript" src="https://cdn.jsdelivr.net/npm/daterangepicker/daterangepicker.min.js"></script>
<link rel="stylesheet" type="text/css" href="https://cdn.jsdelivr.net/npm/daterangepicker/daterangepicker.css" />

<main>

    <section id="ri-block-editor">
        <?php the_content(); ?>
    </section>

    <div class="container-wrap" id="events-search" >
        <div class="container">

            <form id="search-form" autocomplete="off">
                <div class="search-name">
                    <input type="text" name="q" id="event-name" onKeyUp="showResults(this.value)" placeholder="Search for Events" />
                    <div id="search-results"></div>
                </div>
            </form>
            
            <div class="search-dates">
                <div id="preset-dates">
                    <span>
                        <input type="radio" name="date" id="hidden" value="all">
                        <input type="radio" id="all" name="date" value="all" checked>
                        <label class="date-label" for="all">All</label>
                    </span>
                    <span>
                        <input type="radio" id="today" name="date" value="today">
                        <label class="date-label" for="today">Today</label>
                    </span>
                    <span>
                        <input type="radio" id="week" name="date" value="week">
                        <label class="date-label" for="week">This Week</label>
                    </span>
                    <span>
                        <input type="radio" id="month" name="date" value="month">
                        <label class="date-label" for="month">This Month</label>
                    </span>
                </div>

                <div class="date-range">
                    <label for="datepicker" >or choose date: &nbsp;</label>
                    <input type="text" name="date_range" id="datepicker" value="" />
                </div>
            </div>

        </div>

    </div>

    <?php // event grid
    $events = null; ?>

    <section class="container-wrap event-listing">
        <div class="container posts-loop events" id="event-listings"></div>
        <div id="grid-overlay">
            <div class="loader"></div>
        </div>
    </section>

    <section class="container-wrap gift-cards">
        <div class="container">
            <h2>Gift Cards</h2>
            <p>You can now gift a voucher for Real Ideas ticketed events, workshops and immersive experiences. Once purchased, the recipient can simply use the unique code at checkout when booking via the whats on page or Eventbrite.</p>
            <p>This can be redeemed against 1 ticket per transaction, any remaining balance can be used in future transactions. This is not for any co-work or meeting room purchases.</p>
            <div class="giftcards">
                <button type="button" class="btn" id="load-giftup">Buy Gift Cards</button>
            </div>
        </div>
    </section>

</main>

<script>

    const datesRadioForm = document.getElementById('preset-dates');
    const dateRangePicker = document.getElementById('datepicker');

    function getEvents(dateFilter, dateRange, title) {

        const loader = document.getElementById('grid-overlay');
        loader.style.display = 'block';

        const eventListings = document.getElementById('event-listings');
        eventListings.innerHTML = '';

        var ajaxurl = <?php echo json_encode(admin_url('admin-ajax.php')); ?>;
        nonce = <?php echo json_encode(wp_create_nonce('get_events_for_display_nonce')); ?>;

        // const datesRadioForm = document.getElementById('preset-dates');
        if(!dateFilter) {
            dateFilter = 'all';
            const radioAll = document.querySelector('input[value="all"]');
            radioAll.checked = true;
        }

        jQuery.ajax({
            type: "post",
            dataType: "json",
            url: ajaxurl,
            data: {
                action: 'get_events_for_display',
                nonce: nonce,
                organiser: '<?php echo $organiser; ?>',
                dateFilter: dateFilter,
                dateRange: JSON.stringify(dateRange),
                title: title,
            },
            success: function(response) {

                if(response) {

                    window.searchTerms = response.search_terms;

                    response.listings.forEach(item => {

                        const newItem = document.createElement('article');
                        newItem.className = 'event-preview';

                        var multipleDates = '';
                        if(item.is_series == 1) {
                            multipleDates = '<span class="series"><span class="icon"><?php echo file_get_contents(get_template_directory() . '/assets/img/icons/icon-stack.svg'); ?></span>Multiple dates</span>';
                        }

                        const html = `
                            <div class="inner">
                                <div class="featured-img">
                                    <img class="featured" src="${item.image}" alt="${item.title}" />
                                    <span class="img-overlay"></span>
                                    <a href="${item.link}"></a>
                                </div>
                            </div>
                            <div class="content">  
                                <span class="date">${item.next_date}</span>
                                <span class="time"> ${item.next_time}</span>
                                ${multipleDates}
                                <h1>${item.title}</h1>
                                <p>${item.summary}</p>
                                <a class="btn btn__link" href="${item.link}"><span class="btn__text">Book now</span></a>
                            </div>
                        `;
                        
                        newItem.innerHTML = html;
                        eventListings.appendChild(newItem);

                    });

                    if(response.listings.length == 0) {
                        const html = '<p>There are no events to show. Try adjusting your search.</p>';
                        eventListings.innerHTML = html;
                    }

                    setTimeout(function() {
                        eventListings.style.height = 'auto';
                        loader.style.display = 'none';
                    }, 200);

                }

            }
        });

    }


    // preset radio button
    datesRadioForm.addEventListener('change', function() {

        const searchTitle = document.getElementById('event-name');
        searchTitle.value = '';

        const eventListing = document.getElementById('event-listings');
        var listingHeight = eventListing.offsetHeight;
        eventListing.style.height = listingHeight + 'px';

        const radioButtons = document.querySelectorAll('input[name="date"]');
        radioButtons.forEach(function(radioButton) {
            if (radioButton.checked) {
                const selectedValue = radioButton.value;
                getEvents(selectedValue);
            }
        });

    });


    // date picker
    jQuery('input#datepicker').daterangepicker({
        autoUpdateInput: false,
        locale: {
            format: "DD/MM/YYYY",
            cancelLabel: 'Clear'
        }
    });

    jQuery('input#datepicker').on('apply.daterangepicker', function(ev, picker) {

        const searchTitle = document.getElementById('event-name');
        searchTitle.value = '';

        const radioHidden = document.querySelector('input[name="date"]#hidden');
        radioHidden.checked = true;

        var start = picker.startDate.format('YYYY-MM-DD');
        var end = picker.endDate.format('YYYY-MM-DD');
        jQuery(this).val(start + ' - ' + end);

        var dateRange = {
            'start': start,
            'end': end,
        }
        getEvents(null, dateRange, null);
    });

    jQuery('input#datepicker').on('cancel.daterangepicker', function(ev, picker) {

        const searchTitle = document.getElementById('event-name');
        searchTitle.value = '';

        jQuery(this).val('');
        getEvents('all', null, null);

    });


    // search box autocomplete
    // match input with event titles array
    function autocompleteMatch(input) {
        if (input === '') {
            return [];
        }
        var reg = new RegExp(input, 'i'); // 'i' flag for case-insensitive matching
        return window.searchTerms.filter(function(term) {
            return term.match(reg);
        });
    }

    function showResults(val) {
        res = document.getElementById("search-results");
        res.innerHTML = '';
        let list = '';
        let terms = autocompleteMatch(val);
        for (i = 0; i < terms.length; i++) {
            list += '<li>' + terms[i] + '</li>';
        }
        res.innerHTML = '<ul>' + list + '</ul>';
        if(terms.length > 0) {
            res.style.boxShadow = '1px 1px 3px 1px rgba(0,0,0, 0.2)';
        } else {
            res.style.boxShadow = 'none';
        }


        // Attach event listeners AFTER creating the list items
        const searchResults = document.querySelectorAll('#search-results li');
        searchResults.forEach(function(item) {
            item.addEventListener('click', function(event) {
                
                const searchTitle = document.getElementById('event-name');
                searchTitle.value = '';

                getEvents(null, null, event.target.textContent);
                res.innerHTML = '';
                res.style.boxShadow = 'none';
                list.innerHTML = '';
            });
        });
    }


    // search form submit
    const searchForm = document.getElementById('search-form');
    searchForm.addEventListener('submit', function(e) {
        e.preventDefault();
        let searchValue = document.getElementById('event-name').value;
        getEvents(null, null, searchValue);
    });

    // get events on load
    var presetDateFilter = '<?php echo $dates; ?>';
    getEvents(presetDateFilter, null, null);

</script>

<?php get_footer(); ?>